[pkg-fso-commits] [SCM] FSO frameworkd Debian packaging branch, debian, updated. upstream/0.9.5.5-717-g0f98819

Sebastian Krzyszkowiak seba.dos1 at gmail.com
Sat Aug 6 08:17:59 UTC 2011


The following commit has been merged in the debian branch:
commit 5596996edea0630f2d07fca8de41811caa373462
Author: Sebastian Krzyszkowiak <seba.dos1 at gmail.com>
Date:   Fri Aug 21 20:02:44 2009 +0200

    opimd: catch up with changes in dbus errors

diff --git a/framework/subsystems/opimd/pimd_calls.py b/framework/subsystems/opimd/pimd_calls.py
index 1dc6506..1998895 100644
--- a/framework/subsystems/opimd/pimd_calls.py
+++ b/framework/subsystems/opimd/pimd_calls.py
@@ -370,7 +370,7 @@ class CallDomain(Domain, GenericDomain):
 
         # Make sure the requested call exists
         if num_id >= len(self._entries) or self._entries[num_id]==None:
-            raise InvalidCallID()
+            raise InvalidEntryID()
 
         callif = self._entries[num_id]
         call = callif.get_fields(callif._field_idx)
diff --git a/framework/subsystems/opimd/pimd_messages.py b/framework/subsystems/opimd/pimd_messages.py
index c70d3b1..74e6b0b 100644
--- a/framework/subsystems/opimd/pimd_messages.py
+++ b/framework/subsystems/opimd/pimd_messages.py
@@ -1063,10 +1063,10 @@ class MessageDomain(Domain):
 
     def check_message_id_ok( self, num_id ):
         """
         Checks whether the given message id is valid. Raises InvalidMessageID, if not.
         """
         if num_id >= len(self._messages) or self._messages[num_id]==None:
-            raise InvalidMessageID()
+            raise InvalidEntryID()
 
     @dbus_method(_DIN_ENTRY, "", "a{sv}", rel_path_keyword="rel_path")
     def GetContent(self, rel_path):
@@ -1126,7 +1126,7 @@ class MessageDomain(Domain):
 
         # Make sure the requested message exists
         if num_id >= len(self._messages) or self._messages[num_id]==None:
-            raise InvalidMessageID()
+            raise InvalidEntryID()
 
         messageif = self._messages[num_id]
         message = messageif.get_fields(messageif._field_idx)
@@ -1191,7 +1191,7 @@ class MessageDomain(Domain):
 
         # Make sure the requested message exists
         if num_id >= len(self._messages) or self._messages[num_id]==None:
-            raise InvalidMessageID()
+            raise InvalidEntryID()
 
         backends = self._messages[num_id]._used_backends
 
@@ -1063,10 +1063,10 @@ class MessageDomain(Domain):
     def check_message_id_ok( self, num_id ):
         """
-        Checks whether the given message id is valid. Raises InvalidMessageID, if not.
+        Checks whether the given message id is valid. Raises InvalidEntryID, if not.
         """
         if num_id >= len(self._messages) or self._messages[num_id]==None:

-- 
FSO frameworkd Debian packaging



More information about the pkg-fso-commits mailing list